@@ -36,6 +36,16 @@ class AddGatewayRequest(RpcRequest):
 
 	def set_InternetSlbSpec(self, InternetSlbSpec):  # String
 		self.add_query_param('InternetSlbSpec', InternetSlbSpec)
+	def get_EnableXtrace(self): # Boolean
+		return self.get_query_params().get('EnableXtrace')
+
+	def set_EnableXtrace(self, EnableXtrace):  # Boolean
+		self.add_query_param('EnableXtrace', EnableXtrace)
+	def get_XtraceRatio(self): # String
+		return self.get_query_params().get('XtraceRatio')
+
+	def set_XtraceRatio(self, XtraceRatio):  # String
+		self.add_query_param('XtraceRatio', XtraceRatio)
 	def get_Replica(self): # Integer
 		return self.get_query_params().get('Replica')
 
@@ -46,16 +56,40 @@ class AddGatewayRequest(RpcRequest):
 
 	def set_VSwitchId2(self, VSwitchId2):  # String
 		self.add_query_param('VSwitchId2', VSwitchId2)
+	def get_EnableHardwareAcceleration(self): # Boolean
+		return self.get_query_params().get('EnableHardwareAcceleration')
+
+	def set_EnableHardwareAcceleration(self, EnableHardwareAcceleration):  # Boolean
+		self.add_query_param('EnableHardwareAcceleration', EnableHardwareAcceleration)
+	def get_EnableSls(self): # Boolean
+		return self.get_query_params().get('EnableSls')
+
+	def set_EnableSls(self, EnableSls):  # Boolean
+		self.add_query_param('EnableSls', EnableSls)
 	def get_Spec(self): # String
 		return self.get_query_params().get('Spec')
 
 	def set_Spec(self, Spec):  # String
 		self.add_query_param('Spec', Spec)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_EnterpriseSecurityGroup(self): # Boolean
 		return self.get_query_params().get('EnterpriseSecurityGroup')
 
 	def set_EnterpriseSecurityGroup(self, EnterpriseSecurityGroup):  # Boolean
 		self.add_query_param('EnterpriseSecurityGroup', EnterpriseSecurityGroup)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
 	def get_Vpc(self): # String
 		return self.get_query_params().get('Vpc')
 
