@@ -19,6 +19,7 @@
 
 from aliyunsdkcore.request import RpcRequest
 from aliyunsdkmse.endpoint import endpoint_data
+import json
 
 class CreateOrUpdateSwimmingLaneRequest(RpcRequest):
 
@@ -51,6 +52,11 @@ class CreateOrUpdateSwimmingLaneRequest(RpcRequest):
 
 	def set_LicenseKey(self, LicenseKey):  # String
 		self.add_query_param('LicenseKey', LicenseKey)
+	def get_GatewaySwimmingLaneRouteJson(self): # Struct
+		return self.get_query_params().get('GatewaySwimmingLaneRouteJson')
+
+	def set_GatewaySwimmingLaneRouteJson(self, GatewaySwimmingLaneRouteJson):  # Struct
+		self.add_query_param("GatewaySwimmingLaneRouteJson", json.dumps(GatewaySwimmingLaneRouteJson))
 	def get_EntryRule(self): # String
 		return self.get_query_params().get('EntryRule')
 
@@ -79,32 +85,35 @@ class CreateOrUpdateSwimmingLaneRequest(RpcRequest):
 			if EntryRules[depth1].get('RestItems') is not None:
 				for depth2 in range(len(EntryRules[depth1].get('RestItems'))):
 					if EntryRules[depth1].get('RestItems')[depth2].get('Datum') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Datum', EntryRules[depth1].get('RestItems')[depth2].get('Datum'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Datum', EntryRules[depth1].get('RestItems')[depth2].get('Datum'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('Divisor') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Divisor', EntryRules[depth1].get('RestItems')[depth2].get('Divisor'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Divisor', EntryRules[depth1].get('RestItems')[depth2].get('Divisor'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('Rate') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Rate', EntryRules[depth1].get('RestItems')[depth2].get('Rate'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Rate', EntryRules[depth1].get('RestItems')[depth2].get('Rate'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('NameList') is not None:
 						for depth3 in range(len(EntryRules[depth1].get('RestItems')[depth2].get('NameList'))):
-							self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.NameList' + str(depth3 + 1), EntryRules[depth1].get('RestItems')[depth2].get('NameList')[depth3])
+							self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.NameList.' + str(depth3 + 1), EntryRules[depth1].get('RestItems')[depth2].get('NameList')[depth3])
 					if EntryRules[depth1].get('RestItems')[depth2].get('Name') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Name', EntryRules[depth1].get('RestItems')[depth2].get('Name'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Name', EntryRules[depth1].get('RestItems')[depth2].get('Name'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('Type') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Type', EntryRules[depth1].get('RestItems')[depth2].get('Type'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Type', EntryRules[depth1].get('RestItems')[depth2].get('Type'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('Cond') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Cond', EntryRules[depth1].get('RestItems')[depth2].get('Cond'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Cond', EntryRules[depth1].get('RestItems')[depth2].get('Cond'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('Remainder') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Remainder', EntryRules[depth1].get('RestItems')[depth2].get('Remainder'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Remainder', EntryRules[depth1].get('RestItems')[depth2].get('Remainder'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('Value') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Value', EntryRules[depth1].get('RestItems')[depth2].get('Value'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Value', EntryRules[depth1].get('RestItems')[depth2].get('Value'))
 					if EntryRules[depth1].get('RestItems')[depth2].get('Operator') is not None:
-						self.add_query_param('EntryRules.' + str(depth1 + 1) + str(depth2 + 1) + '.Operator', EntryRules[depth1].get('RestItems')[depth2].get('Operator'))
+						self.add_query_param('EntryRules.' + str(depth1 + 1) + '.RestItems.'  + str(depth2 + 1) + '.Operator', EntryRules[depth1].get('RestItems')[depth2].get('Operator'))
 			if EntryRules[depth1].get('Path') is not None:
 				self.add_query_param('EntryRules.' + str(depth1 + 1) + '.Path', EntryRules[depth1].get('Path'))
 			if EntryRules[depth1].get('Condition') is not None:
 				self.add_query_param('EntryRules.' + str(depth1 + 1) + '.Condition', EntryRules[depth1].get('Condition'))
 			if EntryRules[depth1].get('Enable') is not None:
 				self.add_query_param('EntryRules.' + str(depth1 + 1) + '.Enable', EntryRules[depth1].get('Enable'))
+			if EntryRules[depth1].get('Paths') is not None:
+				for depth2 in range(len(EntryRules[depth1].get('Paths'))):
+					self.add_query_param('EntryRules.' + str(depth1 + 1) + '.Paths.' + str(depth2 + 1), EntryRules[depth1].get('Paths')[depth2])
 			if EntryRules[depth1].get('Priority') is not None:
 				self.add_query_param('EntryRules.' + str(depth1 + 1) + '.Priority', EntryRules[depth1].get('Priority'))
 	def get_GroupId(self): # Long
