@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class QueryConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'QueryConfig')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'QueryConfig','mse')
 		self.set_method('GET')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,11 @@ class QueryConfigRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_NeedRunningConf(self): # Boolean
+		return self.get_query_params().get('NeedRunningConf')
+
+	def set_NeedRunningConf(self, NeedRunningConf):  # Boolean
+		self.add_query_param('NeedRunningConf', NeedRunningConf)
 	def get_ConfigType(self): # String
 		return self.get_query_params().get('ConfigType')
 
