@@ -46,6 +46,11 @@ class UpdateConfigRequest(RpcRequest):
 
 	def set_PassWord(self, PassWord):  # String
 		self.add_query_param('PassWord', PassWord)
+	def get_SnapshotCount(self): # String
+		return self.get_query_params().get('SnapshotCount')
+
+	def set_SnapshotCount(self, SnapshotCount):  # String
+		self.add_query_param('SnapshotCount', SnapshotCount)
 	def get_MinSessionTimeout(self): # String
 		return self.get_query_params().get('MinSessionTimeout')
 
@@ -66,11 +71,21 @@ class UpdateConfigRequest(RpcRequest):
 
 	def set_JuteMaxbuffer(self, JuteMaxbuffer):  # String
 		self.add_query_param('JuteMaxbuffer', JuteMaxbuffer)
+	def get_NamingAuthEnabled(self): # Boolean
+		return self.get_query_params().get('NamingAuthEnabled')
+
+	def set_NamingAuthEnabled(self, NamingAuthEnabled):  # Boolean
+		self.add_query_param('NamingAuthEnabled', NamingAuthEnabled)
 	def get_ConfigType(self): # String
 		return self.get_query_params().get('ConfigType')
 
 	def set_ConfigType(self, ConfigType):  # String
 		self.add_query_param('ConfigType', ConfigType)
+	def get_ExtendedTypesEnable(self): # String
+		return self.get_query_params().get('ExtendedTypesEnable')
+
+	def set_ExtendedTypesEnable(self, ExtendedTypesEnable):  # String
+		self.add_query_param('ExtendedTypesEnable', ExtendedTypesEnable)
 	def get_AutopurgeSnapRetainCount(self): # String
 		return self.get_query_params().get('AutopurgeSnapRetainCount')
 
